@@ -22,10 +22,11 @@ User::Simple::Admin - User::Simple user administration
   $id = $ua->id($login);
   $login = $ua->login($id);
 
-  $otherattrib = $user->otherattrib;
+  $otherattrib = $user->otherattrib($id);
 
   $ok = $usr->set_login($id, $login);
   $ok = $usr->set_passwd($id, $passwd);
+  $ok = $usr->set_otherattrib($id, $value);
   $ok = $usr->clear_session($id);
 
   $id = $ua->new_user(login => $login, passwd => $passwd, 
@@ -158,15 +159,15 @@ had been called.
 
 Modifies the requested attribute of the specified user, setting it to the new 
 value. Except for the login, they can all be set to null values - If the 
-password is set to a null value, the account will be locked (that is, no
-password will be accepted). The internal attributes C<id>, C<session> and 
+password is set to a null or empty value, the account will be locked (that is, 
+no password will be accepted). The internal attributes C<id>, C<session> and 
 C<session_exp> cannot be directly modified (you have the C<id> as the hash 
 keys).
 
 Just as with the accessors, if you have extra columns, you can modify them the
 same way:
 
-  $ok = $usr->set_otherattrib($id);
+  $ok = $usr->set_otherattrib($id, $value);
 
 i.e.
 
@@ -379,14 +380,19 @@ sub login {
 # We need only the mutators for the special case fields - Handle everything
 # else via AUTOLOAD
 sub set_login { 
-    my ($self, $id, $new, $sth, $ret);
+    my ($self, $id, $new, $sth, $ret, $used);
     $self = shift;
     $id = shift;
     $new = shift;
 
     return undef unless $id;
 
-    if (my $used = $self->id($new)) {
+    # Setting the login to the current login? Noop doomed to fail, make it look
+    # as a success
+    $used = $self->id($new);
+    return 1 if $used and $used == $self->id($self->login($id));
+
+    if ($used) {
 	carp "The requested login is already used (ID $used).";
 	return undef;
     }
@@ -515,7 +521,7 @@ sub new_user {
 	$id++;
 
 	$sth = $db->prepare("INSERT INTO $self->{tbl} (id, login) 
-            VALUES (?, ?, ?, ?)");
+            VALUES (?, ?)");
 	$sth->execute($id, $param{login});
 
 	# But just to be sure, lets retreive the ID from the login.
